@@ -1,4 +1,4 @@
-#define QT_ACCESSIBILITY_ATSPI_BRIDGE
+#define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE
 #define QT_FREETYPE
 #define QT_NO_OPENGL_ES
 #define QT_NO_OPENGL_ES_2
